@@ -1,15 +1,8 @@
-/* ============================================================
-*
-* This file is part of the KDE project
-*
-* Date        : 2008-11-15
-* Description :Selection QGraphicsItem for the image viewer.
-*
-* SPDX-FileCopyrightText: 2008 Kare Sars <kare dot sars at iki dot fi>
-*
-* SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
-*
-* ============================================================ */
+/*
+ * SPDX-FileCopyrightText: 2008 Kare Sars <kare dot sars at iki dot fi>
+ *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ */
 #ifndef SELECTIONITEM_H
 #define SELECTIONITEM_H
 
@@ -19,6 +12,9 @@
 namespace KSaneIface
 {
 
+/**
+ * Selection QGraphicsItem for the image viewer.
+ */
 class SelectionItem : public QGraphicsItem
 {
 public:
@@ -37,7 +33,7 @@ public:
     } Intersects;
 
     explicit SelectionItem(const QRectF &rect);
-    ~SelectionItem();
+    ~SelectionItem() override;
 
     void setMaxRight(qreal maxRight);
     void setMaxBottom(qreal maxBottom);
